# SearchSource: DBLP

Note: This document is currently under development. It will contain the following elements.

- description
- coverage (disciplines, types of work): Computer science disciplines
- supported (details): run_search (including updates), load,  prep (including get_masterdata)

[DBLP](https://dblp.org/)

License: [Open Data Commons ODC-BY 1.0 license](https://dblp.org/db/about/copyright.html)

## Add the search source

Run a search on dblp.org and paste the url in the following command:

```
colrev search -a colrev.dblp -p "https://dblp.org/search?q=microsourcing"
```

## Links
